<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Crypto;
use App\Models\Fiat;
use App\Models\FiatGateway;
use App\Models\Vcurrency;
use App\Models\Window;
use App\Lib\Tatum;
use App\Rules\FileTypeValidate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ErcController extends Controller {
    
   
    
    public function erccryptoNew()
    {
        $pageTitle = 'Add New ERC20 Token';

        return view('admin.crypto.ercnew',compact('pageTitle'));
    }
    
    public function erccryptoStore(Request $request)
    {
        $request->validate([
            'name'          => 'required',
            'token' => 'required',
            'contractaddress' => 'required',
            'intsupply' => 'required',
            'code'          => 'required|max:10',
            'symbol'        => 'required|max:5',
            'rate'          => 'required|numeric|gt:0',
            
            'wc_fixed'      => 'required|numeric',
            'wc_percent'    => 'required|numeric|max:100',
            'image'         => ['required','image',new FileTypeValidate(['jpeg', 'jpg', 'png'])]
        ]);

        $cryptoImage = null;

        if($request->hasFile('image')) {
            try{
                $location   = imagePath()['crypto']['path'];
                $size       = imagePath()['crypto']['size'];

                $cryptoImage = uploadImage($request->image, $location , $size);

            }catch(\Exception $exp) {
                return back()->withNotify(['error', 'Could not upload the image.']);
            }
        }
         $cps = new Tatum();
         $req = array(
             'token' => $request->token,
             'name' => $request->name,
             'intsupply' => $request->intsupply,
             
         );
         
         if($request->name == "ETH"){
             $chain = "ETH";
         }
         if($request->name == "BSC"){
             $chain = "BSC";
         }
         $connect = $cps->erc20connect($req,$chain);
         
         $reqc = array(
            'token' => $request->token,
            'contractaddress' => $request->contractaddress,
             
         );
         $contract = $cps->addcontract($reqc);
           if($request->name == "ETH"){        
         $result = $cps->createwallet("ethereum");
           }
            if($request->name == "BSC"){
                $result = $cps->createwallet("bsc");
            }
         $private = $cps->privatekey($result->mnemonic);
         
        $crypto             = new Crypto();
        $crypto->xpub = isset($result->xpub) ? $result->xpub : $result->address;
        $crypto->private_key = isset($private->key) ? $private->key : null;
        $crypto->mnemonic = isset($result->mnemonic) ? $result->mnemonic : null;
        $crypto->secret = isset($result->secret) ? $result->secret : null;
        $crypto->name       = $request->name;
        $crypto->token       = isset($request->token) ? $request->token : null;
        $crypto->chain       = isset($request->chain) ? $request->chain : null;
        $crypto->intsupply = isset($request->intsupply) ? $request->intsupply : null;
        $crypto->contractaddress = isset($request->contractaddress) ? $request->contractaddress : null;
          if($request->name == "ETH"){    
        $crypto->erc20 = true;
          }
           if($request->name == "BSC"){
               $crypto->bep20 = true;
           }
        $crypto->code       = $request->token;
        $crypto->symbol     = $request->symbol;
        $crypto->rate       = $request->rate;
        $crypto->dc_fixed   = $request->dc_fixed ? $request->dc_fixed : 0;
        $crypto->dc_percent = $request->dc_percent ? $request->dc_percent : 0;
        $crypto->wc_fixed   = $request->wc_fixed;
        $crypto->wc_percent = $request->wc_percent;
        $crypto->image      = $cryptoImage;
        
        $resultva = $cps->createva($crypto->token,$crypto->xpub);
        $depaddress = $cps->vadeposit($resultva->id,0);
        $crypto->mastervaid = $resultva->id;
        $crypto->wallet_address = $depaddress->address;
        
        $crypto->save();

        $notify[] = ['success', 'Crypto currency has been added'];
        return back()->withNotify($notify);
    }
    
    public function erccryptoEdit($id)
    {
        $crypto = Crypto::findOrFail($id);
        $pageTitle = 'Update '.$crypto->name;

        return view('admin.crypto.ercedit',compact('pageTitle' ,'crypto'));
    }

    public function erccryptoUpdate(Request $request, $id)
    {
        $crypto = Crypto::findOrFail($id);

        $request->validate([
            'name' => 'required|max:40',
            'code' => 'required|max:10',
            'symbol' => 'required|max:5',
            'rate' => 'required|numeric|gt:0',
           
            'wc_fixed' => 'required|numeric',
            'wc_percent' => 'required|numeric|max:100',
            'image' => ['nullable','image',new FileTypeValidate(['jpeg', 'jpg', 'png'])]
        ]);

        $cryptoImage = $crypto->image;

        if($request->hasFile('image')) {
            try{

                $location = imagePath()['crypto']['path'];
                $size = imagePath()['crypto']['size'];
                $old = $crypto->image;
                $cryptoImage = uploadImage($request->image, $location , $size, $old);

            }catch(\Exception $exp) {
                return back()->withNotify(['error', 'Could not upload the image.']);
            }
        }

        $crypto->name = $request->name;
        $crypto->code = $request->code;
        $crypto->symbol = $request->symbol;
        $crypto->rate = $request->rate;
        $crypto->dc_fixed   = $request->dc_fixed ? $request->dc_fixed : 0;
        $crypto->dc_percent = $request->dc_percent ? $request->dc_percent : 0;
        $crypto->wc_fixed = $request->wc_fixed;
        $crypto->wc_percent = $request->wc_percent;
        $crypto->status = $request->status ? 1 : 0;
        $crypto->image = $cryptoImage;
        $crypto->save();

        $notify[] = ['success', 'Crypto currency has been updated'];
        return back()->withNotify($notify);
    }

    public function erccryptoSearch(Request $request)
    {
        $search = $request->search;
        $pageTitle = 'Crypto Currency Search - '. $search;
        $emptyMessage = 'No data found';
        $cryptos = Crypto::where('name', 'like',"%$search%")->orWhere('code', 'like',"%$search%")->latest()->paginate(getPaginate());

        return view('admin.crypto.ercindex',compact('search', 'pageTitle' , 'emptyMessage','cryptos'));
    }
}




?>