<?php

namespace App\Http\Controllers\Admin;

use App\Models\GeneralSetting;
use App\Http\Controllers\Controller;
use App\Models\Transaction;
use App\Models\User;
use App\Models\Crypto;
use App\Lib\Tatum;
use App\Models\Wallet;
use App\Models\WalletCrypto;
use App\Models\WithdrawMethod;
use App\Models\Withdrawal;
use Carbon\Carbon;
use Illuminate\Http\Request;

class WithdrawalcController extends Controller
{
    public function pending()
    {
        $pageTitle = 'Pending Withdrawals';
        $withdrawals = Withdrawal::pending()->with(['user','method'])->where('crypto_id', '!=', null)->orderBy('id','desc')->paginate(getPaginate());
        $emptyMessage = 'No withdrawal found';
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'withdrawals', 'emptyMessage'));
    }
    
    public function approved()
    {
        $pageTitle = 'Approved Withdrawals';
        $withdrawals = Withdrawal::approved()->with(['user','method'])->where('crypto_id', '!=', null)->orderBy('id','desc')->paginate(getPaginate());
        $emptyMessage = 'No withdrawal found';
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'withdrawals', 'emptyMessage'));
    }

    public function rejected()
    {
        $pageTitle = 'Rejected Withdrawals';
        $withdrawals = Withdrawal::rejected()->with(['user','method'])->where('crypto_id', '!=', null)->orderBy('id','desc')->paginate(getPaginate());
        $emptyMessage = 'No withdrawal found';
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'withdrawals', 'emptyMessage'));
    }

    public function log()
    {
        $pageTitle = 'Withdrawals Log';
        $withdrawals = Withdrawal::where('status', '!=', 0)->where('crypto_id', '!=', null)->with(['user','method'])->orderBy('id','desc')->paginate(getPaginate());
        $emptyMessage = 'No withdrawal history';
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'withdrawals', 'emptyMessage'));
    }


    public function logViaMethod($methodId,$type = null){
        $method = WithdrawMethod::findOrFail($methodId);
        if ($type == 'approved') {
            $pageTitle = 'Approved Withdrawal Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 1)->with(['user','method'])->where('crypto_id', '!=', null)->where('method_id',$method->id)->orderBy('id','desc')->paginate(getPaginate());
        }elseif($type == 'rejected'){
            $pageTitle = 'Rejected Withdrawals Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 3)->with(['user','method'])->where('crypto_id', '!=', null)->where('method_id',$method->id)->orderBy('id','desc')->paginate(getPaginate());

        }elseif($type == 'pending'){
            $pageTitle = 'Pending Withdrawals Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 2)->with(['user','method'])->where('crypto_id', '!=', null)->where('method_id',$method->id)->orderBy('id','desc')->paginate(getPaginate());
        }else{
            $pageTitle = 'Withdrawals Via '.$method->name;
            $withdrawals = Withdrawal::where('status', '!=', 0)->with(['user','method'])->where('crypto_id', '!=', null)->where('method_id',$method->id)->orderBy('id','desc')->paginate(getPaginate());
        }
        $emptyMessage = 'No withdrawal found';
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'withdrawals', 'emptyMessage','method'));
    }


    public function search(Request $request, $scope)
    {
        $search = $request->search;
        $emptyMessage = 'No search result found.';

        $withdrawals = Withdrawal::with(['user', 'method'])->where('status','!=',0)->where('crypto_id', '!=', null)->where(function ($q) use ($search) {
            $q->where('trx', 'like',"%$search%")
                ->orWhereHas('user', function ($user) use ($search) {
                    $user->where('username', 'like',"%$search%");
                });
        });

        if ($scope == 'pending') {
            $pageTitle = 'Pending Withdrawal Search';
            $withdrawals = $withdrawals->where('status', 2);
        }elseif($scope == 'approved'){
            $pageTitle = 'Approved Withdrawal Search';
            $withdrawals = $withdrawals->where('status', 1);
        }elseif($scope == 'rejected'){
            $pageTitle = 'Rejected Withdrawal Search';
            $withdrawals = $withdrawals->where('status', 3);
        }else{
            $pageTitle = 'Withdrawal History Search';
        }

        $withdrawals = $withdrawals->paginate(getPaginate());
        $pageTitle .= ' - ' . $search;

        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'emptyMessage', 'search', 'scope', 'withdrawals'));
    }

    public function dateSearch(Request $request,$scope){
        $search = $request->date;
        if (!$search) {
            return back();
        }
        $date = explode('-',$search);
        $start = @$date[0];
        $end = @$date[1];

        // date validation
        $pattern = "/\d{2}\/\d{2}\/\d{4}/";
        if ($start && !preg_match($pattern,$start)) {
            $notify[] = ['error','Invalid date format'];
            return redirect()->route('admin.withdraw.log')->withNotify($notify);
        }
        if ($end && !preg_match($pattern,$end)) {
            $notify[] = ['error','Invalid date format'];
            return redirect()->route('admin.withdraw.log')->withNotify($notify);
        }


        if ($start) {
            $withdrawals = Withdrawal::where('status','!=',0)->where('crypto_id', '!=', null)->whereDate('created_at',Carbon::parse($start));
        }
        if($end){
            $withdrawals = Withdrawal::where('status','!=',0)->where('crypto_id', '!=', null)->whereDate('created_at','>=',Carbon::parse($start))->whereDate('created_at','<=',Carbon::parse($end));
        }
        if ($request->method) {
            $method = WithdrawMethod::findOrFail($request->method);
            $withdrawals = $withdrawals->where('method_id',$method->id);
        }

        if ($scope == 'pending') {
            $withdrawals = $withdrawals->where('status', 2);
        }elseif($scope == 'approved'){
            $withdrawals = $withdrawals->where('status', 1);
        }elseif($scope == 'rejected') {
            $withdrawals = $withdrawals->where('status', 3);
        }

        $withdrawals = $withdrawals->with(['user', 'method'])->where('crypto_id', '!=', null)->paginate(getPaginate());
        $pageTitle = 'Withdraw Log';
        $emptyMessage = 'No Withdrawals Found';
        $dateSearch = $search;
        return view('admin.withdrawc.withdrawals', compact('pageTitle', 'emptyMessage', 'dateSearch', 'withdrawals','scope'));


    }

    public function details($id)
    {
        $general = GeneralSetting::first();
        $withdrawal = Withdrawal::where('id',$id)->where('crypto_id', '!=', null)->where('status', '!=', 0)->with(['user','method'])->firstOrFail();
        $pageTitle = $withdrawal->user->username.' Withdraw Requested ' . getAmount($withdrawal->amount) . ' '.$withdrawal->crypto->code;
        $details = $withdrawal->withdraw_information ? json_encode($withdrawal->withdraw_information) : null;



        

        return view('admin.withdrawc.detail', compact('pageTitle', 'withdrawal','details'));
    }

    public function approve(Request $request)
    {
        $request->validate(['id' => 'required|integer']);
        $withdraw = Withdrawal::where('id',$request->id)->where('crypto_id', '!=', null)->where('status',2)->with('user')->firstOrFail();
         $crypto = Crypto::where('id',$withdraw->crypto_id)->first();
        
         if($crypto->erc20 == true || $crypto->bep20 == true){ 
             $walletcrypto = WalletCrypto::where('user_id',$withdraw->user_id)->where('crypto_id',$withdraw->crypto_id)->first();
         $va = $crypto->mastervaid;
            $t = new Tatum();
            $unblk = $t->unblockamount($withdraw->blockid,$va,$withdraw->amount);
            if(isset($unblk->statusCode) && $unblk->statusCode != 200){
               $notify[] = ['error', 'Error Processing Withdrawal '.$unblk->message];
        return redirect()->route('admin.withdrawc.pending')->withNotify($notify);  
            }
            
            $receiverwallet = WalletCrypto::where('wallet_address',$withdraw->wallet_address)->where('crypto_id',$withdraw->crypto_id)->first();
            if(isset($receiverwallet->customerid)){
             $send = $t->sendpayment($va,$receiverwallet->customerid,$withdraw->payable); 
            } else {
            
            $send = $t->sendaddress($va,$withdraw->wallet_address,$withdraw->payable,$crypto->private_key);
            }
            if(isset($send->statusCode) && $send->statusCode != 200){
                $sendpayment = $t->sendpayment($va,$walletcrypto->customerid,$withdraw->amount);
                $block = $t->blockamount($walletcrypto->customerid,$withdraw->amount);
                $withdraw->blockid = $block->id;
                $withdraw->save();
                $cause = isset($send->cause) ? $send->cause : "";
               $notify[] = ['error', $send->message.'Error Processing '.$cause];
        return redirect()->route('admin.withdrawc.pending')->withNotify($notify); 
            }
           
            
         }
        $withdraw->status = 1;
        $withdraw->admin_feedback = $request->details;
        $withdraw->save();
        
        $general = GeneralSetting::first();
         $bal = $t->vabalance($receiverwallet->customerid);
          $transaction = new Transaction();
            $transaction->user_id = $receiverwallet->user_id;
            $transaction->amount = $withdraw->payable;
            $transaction->post_balance = $bal->balance->availableBalance;
            $transaction->charge = 0;
            $transaction->crypto_id = $withdraw->crypto_id;
            $transaction->trx_type = '+';
            $transaction->details = $request->details;
            $transaction->trx = getTrx();
            $transaction->save();
        
        notify($withdraw->user, 'WITHDRAW_APPROVE', [
            
            'method_amount' => getAmount($withdraw->payable),
            'amount' => getAmount($withdraw->amount),
            'charge' => getAmount($withdraw->charge),
            'currency' => $withdraw->crypto->code,
            'rate' => getAmount($withdraw->rate),
            'trx' => $withdraw->trx,
            'admin_details' => $request->details
        ]);

        $notify[] = ['success', 'Withdrawal marked as approved.'];
        return redirect()->route('admin.withdrawc.pending')->withNotify($notify);
    }


    public function reject(Request $request)
    {
        $general = GeneralSetting::first();
        $request->validate(['id' => 'required|integer']);
        $withdraw = Withdrawal::where('id',$request->id)->where('crypto_id', '!=', null)->where('status',2)->firstOrFail();
        $crypto = Crypto::where('status',1)->where('code',$request->crypto)->firstOrFail();
        $userBalance = Wallet::where('user_id',$user->id)->where('crypto_id',$crypto->id)->firstOrFail();
        
        $withdraw->status = 3;
        $withdraw->admin_feedback = $request->details;
        $withdraw->save();
           if($crypto->erc20 == true || $crypto->bep20 == true){ 
             
            $t = new Tatum();
            $unblk = $t->releaseamount($withdraw->blockid);
           
         }
        $user = User::find($withdraw->user_id);
        $userBalance->balance += $withdraw->amount;
        $userBalance->save();



            $transaction = new Transaction();
            $transaction->user_id = $withdraw->user_id;
            $transaction->amount = $withdraw->amount;
            $transaction->post_balance = $user->balance;
            $transaction->charge = 0;
            $transaction->trx_type = '+';
            $transaction->details = getAmount($withdraw->amount) . ' ' . $withdraw->crypto->code . ' Refunded from withdrawal rejection';
            $transaction->trx = $withdraw->trx;
            $transaction->save();


        

        notify($user, 'WITHDRAW_REJECT', [
            'method_name' => $withdraw->method->name,
            'method_currency' => $withdraw->currency,
            'method_amount' => getAmount($withdraw->final_amount),
            'amount' => getAmount($withdraw->amount),
            'charge' => getAmount($withdraw->charge),
            'currency' => $withdraw->crypto->code,
           
            'trx' => $withdraw->trx,
            'post_balance' => getAmount($userBalance->balance),
            'admin_details' => $request->details
        ]);

        $notify[] = ['success', 'Withdrawal has been rejected.'];
        return redirect()->route('admin.withdrawc.pending')->withNotify($notify);
    }

}
