<?php

namespace App\Http\Controllers\Gateway;

use App\Http\Controllers\Controller;
use App\Models\Crypto;
use App\Models\User;
use App\Models\Wallet;

use App\Models\Points;
use App\Models\WalletCrypto;
use App\Http\Controllers\Gateway\Coinpayments\CoinPaymentHosted;
use App\Lib\Tatum;
use App\Models\AdminNotification;
use App\Models\Deposit;
use App\Models\GatewayCurrency;
use App\Models\GeneralSetting;
use App\Models\Transaction;

use App\Rules\FileTypeValidate;
use Illuminate\Http\Request;

class PaymentController extends Controller
{
    public function __construct()
    {
        return $this->activeTemplate = activeTemplate();
    }
 public function wallets()
    {
        $pageTitle = 'Your Receiving Wallets';
        $wallets = Wallet::where('user_id', auth()->user()->id)->whereHas('crypto', function($q){
            $q->where('status', 1);
        })->with('crypto')->latest()->get();
        $cryptoWallets = WalletCrypto::where('user_id', auth()->user()->id)->whereHas('crypto', function($q){
            $q->where('status', 1);
        })->latest()->with('crypto')->get();
        return view($this->activeTemplate . 'user.wallet', compact('pageTitle', 'wallets','cryptoWallets'));
    }

    public function walletGenerate($code)
    {
         $user = auth()->user(); 
           $general = GeneralSetting::first();
        $crypto = Crypto::where('status',1)->where('code',$code)->firstOrFail();
         $check = WalletCrypto::where('user_id',$user->id)->where('crypto_id',$crypto->id)->first();
           if(isset($check->id)){
               $notify[] = ['error', 'Crypto Wallet Adddress Exists For : '. $code]; 
               return back()->withNotify($notify);
           }

        $coinPayAcc = GeneralSetting::first(['public_key','private_key']);

            $cps = new CoinPaymentHosted();
            $cps->Setup($coinPayAcc->private_key, $coinPayAcc->public_key);
            $callbackUrl = route('ipn.crypto');
            $result = $cps->GetCallbackAddress($crypto->code,$callbackUrl);
            if ($result['error'] == 'ok') {
                $newCryptoWallet = new WalletCrypto();
                $newCryptoWallet->user_id = auth()->user()->id;
                $newCryptoWallet->crypto_id = $crypto->id;
                $newCryptoWallet->wallet_address = $result['result']['address'];
                $newCryptoWallet->save();
                $notify[] = ['success', 'New Wallet Address Generated Successfully'];
            } else {
                $notify[] = ['error', 'API Error : '. $result['error']];
            }

            return back()->withNotify($notify);
    }

    public function ercwalletGenerate($code)
    {
         $crypto = Crypto::where('status',1)->where('token',$code)->firstOrFail();
          $user = auth()->user(); 
           $general = GeneralSetting::first();
           $check = WalletCrypto::where('user_id',$user->id)->where('crypto_id',$crypto->id)->first();
           if(isset($check->id)){
               $notify[] = ['error', 'Crypto Adddress Exists For : '. $code]; 
               return back()->withNotify($notify);
           }

            $cps = new Tatum();
            
            $callbackUrl = route('ipn.erccrypto');
            $result = $cps->createva($crypto->token,$crypto->xpub);
             if(isset($result->statusCode) && $result->statusCode != 200){
                $notify[] = ['error', 'API Error : '. $result->message]; 
                return back()->withNotify($notify);
            }
            
            if(isset($result->id)){
             $address = $cps->vadeposit($result->id);
             if(isset($address->address)){
                $newCryptoWallet = new WalletCrypto();
                $newCryptoWallet->user_id = auth()->user()->id;
                $newCryptoWallet->crypto_id = $crypto->id;
                $newCryptoWallet->wallet_address = $address->address;
                $newCryptoWallet->customerid = $result->id;
                $newCryptoWallet->memo = isset($address->memo) ? $address->memo : null;
                $newCryptoWallet->destinationTag = isset($address->destinationTag) ? $address->destinationTag : null;
                $newCryptoWallet->message = isset($address->message) ? $address->message : null;
                $newCryptoWallet->save();
                $notify[] = ['success', 'New Wallet Address Generated Successfully.'];
             } else {
                 $notify[] = ['error', 'API Error : '. $address->message]; 
             } 
             
          
             $ipn = $cps->createipn($result->id, $callbackUrl);
             

            return back()->withNotify($notify);
    }
    

    }
    public static function cryptoipn(Request $request)
    {

        if ($request->status >= 100 || $request->status == 2) {


            $userCryptoWallet = WalletCrypto::where('wallet_address', $request->address)->first();
            $user       = $userCryptoWallet->user;
            $general = GeneralSetting::first();

            if($general->merchant_id == $request->merchant){

                $exist =  Deposit::where('cp_trx',$request->txn_id)->count();
                if($exist == 0){

                    $crypto = Crypto::find($userCryptoWallet->crypto_id);
                    $sentAmount = $request->amount;

                    $charge                 = $crypto->dc_fixed + ($sentAmount * $crypto->dc_percent / 100);
                    $finalAmount            = $sentAmount - $charge;
                    
                    if($finalAmount > 0){
                        $data                   = new Deposit();
                        $data->user_id          = $user->id;
                        $data->crypto_id        = $crypto->id;
                        $data->wallet_address   = $request->address;
                        $data->amount           = $sentAmount;
                        $data->charge           = $charge;
                        $data->final_amo        = $finalAmount;
                        $data->trx              = getTrx();
                        $data->status           = 1;
                        $data->cp_trx           = $request->txn_id;
                        $data->save();


                        $userWallet = Wallet::where('user_id',$userCryptoWallet->user_id)->where('crypto_id',$userCryptoWallet->crypto_id)->first();
                        $userWallet->balance +=  $finalAmount;
                        $userWallet->save();


                        $transaction = new Transaction();
                        $transaction->user_id = $data->user_id;
                        $transaction->crypto_id = $crypto->id;
                        $transaction->amount = $data->amount;
                        $transaction->post_balance = getAmount($userWallet->balance,8);
                        $transaction->charge = getAmount($data->charge,8);
                        $transaction->trx_type = '+';
                        $transaction->details = 'Deposit Via ' . $data->crypto->code;
                        $transaction->trx = $data->trx;
                        $transaction->save();
                        
                        if($general->points){
                            $point_credit = floor(($data->amount * $general->crypto_perpoints / 100));
                            $points = new Points();
                            $user->point_balance += $point_credit;
                            $user->save();
                            $points->user_id = $data->user_id;
                            $points->crypto_id = $crypto->id;
                            $points->amount = $point_credit;
                            $points->post_balance = $user->point_balance;
                             $points->charge = "0";
                            $points->trx_type = '+';
                            $points->details = 'Points Earned For '.$data->amount.' Deposited Via ' . $data->crypto->code;
                            $points->trx = $data->trx;
                            $points->save();
                            
                            
                            
                        }


                        $adminNotification = new AdminNotification();
                        $adminNotification->user_id = $user->id;
                        $adminNotification->title = 'Deposit successful for '.$data->crypto->code;
                        $adminNotification->click_url = urlPath('admin.deposit.successful');
                        $adminNotification->save();

                        notify($user, 'DEPOSIT_COMPLETE', [
                            'amount' => showAmount($data->amount,8),
                            'charge' => showAmount($data->charge,8),
                            'currency' => $data->crypto->code,
                            'payable' => showAmount($data->final_amo,8),
                            'trx' => $data->trx,
                            'post_balance' => showAmount($userWallet->balance,8)
                        ]);
                    }
                }
            }
        }
    }
    
     public static function erccryptoipn(Request $request)
    {

       


            $userCryptoWallet = WalletCrypto::where('customerid', $request->accountId)->first();
            $user       = $userCryptoWallet->user;
            $general = GeneralSetting::first();

          

                $exist =  Deposit::where('cp_trx',$request->txId)->count();
                 
                if(isset($exist) && $exist == 0){

                    $crypto = Crypto::find($userCryptoWallet->crypto_id);
                    $sentAmount = $request->amount;

                    $charge                 = $crypto->dc_fixed + ($sentAmount * $crypto->dc_percent / 100);
                    $finalAmount            = $sentAmount - $charge;
                    
                    if($finalAmount > 0){
                        $data                   = new Deposit();
                        $data->user_id          = $user->id;
                        $data->crypto_id        = $crypto->id;
                        $data->wallet_address   = $request->to;
                        $data->amount           = $sentAmount;
                        $data->charge           = $charge;
                        $data->final_amo        = $finalAmount;
                        $data->trx              = getTrx();
                        $data->status           = 1;
                        $data->cp_trx           = $request->txId;
                        $data->save();


                        $userWallet = Wallet::where('user_id',$userCryptoWallet->user_id)->where('crypto_id',$userCryptoWallet->crypto_id)->first();
                        $userWallet->balance +=  $finalAmount;
                        $userWallet->save();


                        $transaction = new Transaction();
                        $transaction->user_id = $data->user_id;
                        $transaction->crypto_id = $crypto->id;
                        $transaction->amount = $data->amount;
                        $transaction->post_balance = getAmount($userWallet->balance,8);
                        $transaction->charge = getAmount($data->charge,8);
                        $transaction->trx_type = '+';
                        $transaction->details = 'Deposit Via ' . $data->crypto->code;
                        $transaction->trx = $data->trx;
                        $transaction->save();


                        $adminNotification = new AdminNotification();
                        $adminNotification->user_id = $user->id;
                        $adminNotification->title = 'Deposit successful for '.$data->crypto->code;
                        $adminNotification->click_url = urlPath('admin.deposit.successful');
                        $adminNotification->save();

                        notify($user, 'DEPOSIT_COMPLETE', [
                            'amount' => showAmount($data->amount,8),
                            'charge' => showAmount($data->charge,8),
                            'currency' => $data->crypto->code,
                            'payable' => showAmount($data->final_amo,8),
                            'trx' => $data->trx,
                            'post_balance' => showAmount($userWallet->balance,8)
                        ]);
                        
                        echo "Deposit Credited";
                    }
                }
                
                 echo "Deposit Already Credited";
           
      
    }
    public function returnPage(Request $req){
        dd($req);
        
    }
    public function deposit(Request $req)
    {
        $response = $req->input();
        if(isset($response['pp_ResponseCode'])){
            echo $response['pp_ResponseCode'];
            echo $response['pp_ResponseMessage'];
        }
        $gatewayCurrency = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', 1);
        })->with('method')->orderby('method_code')->get();
        $pageTitle = 'Deposit Methods';
        return view($this->activeTemplate . 'user.payment.deposit', compact('gatewayCurrency', 'pageTitle'));
    }

    public function depositInsert(Request $request)
    {

        $request->validate([
            'amount' => 'required|numeric|gt:0',
            'method_code' => 'required',
            'currency' => 'required',
        ]);


        $user = auth()->user();
        $gate = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', 1);
        })->where('method_code', $request->method_code)->where('currency', $request->currency)->first();
        if (!$gate) {
            $notify[] = ['error', 'Invalid gateway'];
            return back()->withNotify($notify);
        }

        if ($gate->min_amount > $request->amount || $gate->max_amount < $request->amount) {
            $notify[] = ['error', 'Please follow deposit limit'];
            return back()->withNotify($notify);
        }

        $charge = $gate->fixed_charge + ($request->amount * $gate->percent_charge / 100);
        $payable = $request->amount + $charge;
        $final_amo = $payable * $gate->rate;

        $data = new Deposit();
        $data->user_id = $user->id;
        $data->method_code = $gate->method_code;
        $data->method_currency = strtoupper($gate->currency);
        $data->amount = $request->amount;
        $data->charge = $charge;
        $data->rate = $gate->rate;
        $data->final_amo = $final_amo;
        $data->btc_amo = 0;
        $data->btc_wallet = "";
        $data->trx = getTrx();
        $data->try = 0;
        $data->status = 0;
        $data->dp = $request->dp;
        $data->save();
        session()->put('Track', $data->trx);
        return redirect()->route('user.deposit.preview');
    }


    public function depositPreview()
    {

        $track = session()->get('Track');
        $data = Deposit::where('trx', $track)->where('status',0)->orderBy('id', 'DESC')->firstOrFail();
        $pageTitle = 'Payment Preview';
        return view($this->activeTemplate . 'user.payment.preview', compact('data', 'pageTitle'));
    }


    public function depositConfirm()
    {
        $track = session()->get('Track');
        $deposit = Deposit::where('trx', $track)->where('status',0)->orderBy('id', 'DESC')->with('gateway')->firstOrFail();
       
        
        if ($deposit->method_code >= 1000) {
            $this->userDataUpdate($deposit);
            $notify[] = ['success', 'Your deposit request is queued for approval.'];
            return back()->withNotify($notify);
        }


        $dirName = $deposit->gateway->alias;
        $new = __NAMESPACE__ . '\\' . $dirName . '\\ProcessController';
        
        $data = $new::process($deposit);
        $data = json_decode($data);
        

        if (isset($data->error)) {
            $notify[] = ['error', $data->message];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }
        if (isset($data->redirect)) {
            return redirect($data->redirect_url);
        }

        // for Stripe V3
        if(@$data->session){
            $deposit->btc_wallet = $data->session->id;
            $deposit->save();
        }

        $pageTitle = 'Payment Confirm';
        return view($this->activeTemplate . $data->view, compact('data', 'pageTitle', 'deposit'));
    }


    public static function userDataUpdate($trx)
    {
        $general = GeneralSetting::first();
        $data = Deposit::where('trx', $trx)->first();
        if ($data->status == 0) {
            $data->status = 1;
            $data->save();

            $user = User::find($data->user_id);
            $user->balance += $data->amount;
            $user->save();

            $transaction = new Transaction();
            $transaction->user_id = $data->user_id;
            $transaction->amount = $data->amount;
            $transaction->post_balance = $user->balance;
            $transaction->charge = $data->charge;
            $transaction->trx_type = '+';
            $transaction->details = 'Deposit Via ' . $data->gatewayCurrency()->name;
            $transaction->trx = $data->trx;
            $transaction->save();
            
             if($general->points && ($data->amount > $general->fiat_minpoints)){
                            $point_credit = floor(($data->amount * $general->fiat_perpoints / 100));
                            $points = new Points();
                            $user->point_balance += $point_credit;
                            $user->save();
                            $points->user_id = $data->user_id;
                           
                            $points->amount = $point_credit;
                            $points->post_balance = $user->point_balance;
                            $points->charge = "0";
                            $points->trx_type = '+';
                            $points->details = 'Points Earned For '.$data->amount.' Deposited via ' . $data->gatewayCurrency()->name;
                            $points->trx = $data->trx;
                            $points->save();
                            
                            
                            
                        }

            $adminNotification = new AdminNotification();
            $adminNotification->user_id = $user->id;
            $adminNotification->title = 'Deposit successful via '.$data->gatewayCurrency()->name;
            $adminNotification->click_url = urlPath('admin.deposit.successful');
            $adminNotification->save();

            notify($user, 'DEPOSIT_COMPLETE', [
                'method_name' => $data->gatewayCurrency()->name,
                'method_currency' => $data->method_currency,
                'method_amount' => showAmount($data->final_amo),
                'amount' => showAmount($data->amount),
                'charge' => showAmount($data->charge),
                'currency' => $general->cur_text,
                'rate' => showAmount($data->rate),
                'trx' => $data->trx,
                'post_balance' => showAmount($user->balance)
            ]);


        }
    }

    public function manualDepositConfirm()
    {
        $track = session()->get('Track');
        $data = Deposit::with('gateway')->where('status', 0)->where('trx', $track)->first();
        if (!$data) {
            return redirect()->route(gatewayRedirectUrl());
        }
        if ($data->method_code > 999) {

            $pageTitle = 'Deposit Confirm';
            $method = $data->gatewayCurrency();
            return view($this->activeTemplate . 'user.manual_payment.manual_confirm', compact('data', 'pageTitle', 'method'));
        }
        abort(404);
    }

    public function manualDepositUpdate(Request $request)
    {
        $track = session()->get('Track');
        $data = Deposit::with('gateway')->where('status', 0)->where('trx', $track)->first();
        if (!$data) {
            return redirect()->route(gatewayRedirectUrl());
        }

        $params = json_decode($data->gatewayCurrency()->gateway_parameter);

        $rules = [];
        $inputField = [];
        $verifyImages = [];

        if ($params != null) {
            foreach ($params as $key => $custom) {
                $rules[$key] = [$custom->validation];
                if ($custom->type == 'file') {
                    array_push($rules[$key], 'image');
                    array_push($rules[$key], new FileTypeValidate(['jpg','jpeg','png']));
                    array_push($rules[$key], 'max:2048');

                    array_push($verifyImages, $key);
                }
                if ($custom->type == 'text') {
                    array_push($rules[$key], 'max:191');
                }
                if ($custom->type == 'textarea') {
                    array_push($rules[$key], 'max:300');
                }
                $inputField[] = $key;
            }
        }
        $this->validate($request, $rules);


        $directory = date("Y")."/".date("m")."/".date("d");
        $path = imagePath()['verify']['deposit']['path'].'/'.$directory;
        $collection = collect($request);
        $reqField = [];
        if ($params != null) {
            foreach ($collection as $k => $v) {
                foreach ($params as $inKey => $inVal) {
                    if ($k != $inKey) {
                        continue;
                    } else {
                        if ($inVal->type == 'file') {
                            if ($request->hasFile($inKey)) {
                                try {
                                    $reqField[$inKey] = [
                                        'field_name' => $directory.'/'.uploadImage($request[$inKey], $path),
                                        'type' => $inVal->type,
                                    ];
                                } catch (\Exception $exp) {
                                    $notify[] = ['error', 'Could not upload your ' . $inKey];
                                    return back()->withNotify($notify)->withInput();
                                }
                            }
                        } else {
                            $reqField[$inKey] = $v;
                            $reqField[$inKey] = [
                                'field_name' => $v,
                                'type' => $inVal->type,
                            ];
                        }
                    }
                }
            }
            $data->detail = $reqField;
        } else {
            $data->detail = null;
        }



        $data->status = 2; // pending
        $data->save();


        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $data->user->id;
        $adminNotification->title = 'Deposit request from '.$data->user->username;
        $adminNotification->click_url = urlPath('admin.deposit.details',$data->id);
        $adminNotification->save();

        $general = GeneralSetting::first();
        notify($data->user, 'DEPOSIT_REQUEST', [
            'method_name' => $data->gatewayCurrency()->name,
            'method_currency' => $data->method_currency,
            'method_amount' => showAmount($data->final_amo),
            'amount' => showAmount($data->amount),
            'charge' => showAmount($data->charge),
            'currency' => $general->cur_text,
            'rate' => showAmount($data->rate),
            'trx' => $data->trx
        ]);

        $notify[] = ['success', 'You have deposit request has been taken.'];
        return redirect()->route('user.deposit.history')->withNotify($notify);
    }


}
