<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Cart;
use App\Models\Fiat;
use App\Models\Page;
use App\Models\Plan;
use App\Models\Crypto;
use App\Models\Category;
use App\Models\Frontend;
use App\Models\Language;
use App\Models\FiatGateway;
use App\Models\SubCategory;
use App\Models\Transaction;
use App\Http\Helpers\helpers;
use Illuminate\Http\Request;
use App\Models\Advertisement;
use App\Models\SupportTicket;
use App\Models\GeneralSetting;
use App\Models\SupportMessage;
use App\Models\AdminNotification;
use App\Models\SupportAttachment;
use App\Models\Fluttercard;
use App\Lib\Flutterwave;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;


class VirtualCardController extends Controller
{
    public function __construct()
    {
        $this->activeTemplate = activeTemplate();
    }

    
     public function showVirtualCard()
    {
        $pageTitle = 'Virtual Card';
        $emptyMessage = 'No data found';


        $user = auth()->user();
        $virtualcard = FlutterCard::where('user_id', Auth::user()->id)->first();
        if (isset($virtualcard->card_id)) {
            $from = date('Y-m-d', strtotime('-3 months'));
            $to = date('Y-m-d');
            $transaction = new Flutterwave;
            $getTransactions = $transaction->gettransaction($virtualcard->card_id, $from, $to);
            //Check if transaction retrieval was successful
            if (!$getTransactions || !isset($getTransactions) || empty($getTransactions)) {
                $notify[] = ['error', 'Failed to fetch transactions'];
                return back()->withNotify($notify)->withInput();
            }
            // Decode the JSON string
            $decodedTransactions = json_decode($getTransactions, true);
            // dd($decodedTransactions); die;
            
        } else {
            $getTransactions = null;
        }
        return view($this->activeTemplate . 'user.virtualcard.showVirtualCard', compact('pageTitle', 'emptyMessage', 'virtualcard', 'user','decodedTransactions'));
    }
     public function newVirtualCard(Request $request)
    {

        $user = auth()->user();
        $general = GeneralSetting::first();
        $validator = Validator::make($request->all(), [
            'currency' => 'required|string', // Adjust validation rules as needed
            'amount' => 'required|numeric',
            'first_name' => 'required|string',
            'last_name' => 'required|string',
            'date_of_birth' => 'required|date',
            'email' => 'required|email',
            'phone' => 'required|string',
            'title' => 'required|string',
            'gender' => 'required|string',
        ]);

        // Check if validation fails
        if ($validator->fails()) {
            $notify[] = ['error', 'Validation failed'];
        }
        $validatedData = $validator->validated();

        // Convert USD amount to cents
        if ($validatedData['currency'] == 'USD') {
            $usd_amount_float = floatval($validatedData['amount']);
            $usd_to_cents = $usd_amount_float * 100;
            //  dd($usd_to_cents); die;
            $validatedData['amount'] = $usd_to_cents;
            // Retrieve the issue fee from general settings
            $issueFee = $general->flutter_issue * 100; // Assuming flutter_issue is the issue fee

        }
        $Totalamount = $validatedData['amount'] + $issueFee;


        if ($Totalamount > $user->balance * 100) {
            $notify[] = ['error', 'Sorry! insufficient balance in this wallet'];
            return back()->withNotify($notify)->withInput();
        }

        $trx = getTrx();

        $user->balance -= $issueFee / 100; // Convert amount back to USD before deduction
        $user->save();
        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = $issueFee / 100; // Convert amount back to USD for recording in 
        $transaction->post_balance = $user->balance;
        $transaction->charge = 00;
        $transaction->trx_type = '-';
        $transaction->details = 'Card Issuance Fees';
        $transaction->trx =  $trx;
        $transaction->save();

        $ntrx = getTrx();

        $user->balance -= $validatedData['amount'] / 100; // Convert amount back to USD before deduction
        $user->save();

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = $validatedData['amount'] / 100; // Convert amount back to USD for recording in the transaction
        $transaction->post_balance = $user->balance;
        $transaction->charge = 00;
        $transaction->trx_type = '-';
        $transaction->details = 'Initial  Card Loading';
        $transaction->trx =  $ntrx;
        $transaction->save();
        // Assuming $payment_request is included in the request data

        $payment_request = $validatedData;
        $newcards = new Flutterwave;
        $virtualcard_api_response = $newcards->fluttercard($payment_request);
        // dd($virtualcard_api_response); die;

        if (empty($virtualcard_api_response)) {
            $notify[] = ['error', ' Something went wrong while processing Request'];
            return redirect()->back()->withNotify($notify);
        } elseif ($virtualcard_api_response->status == "error") {
            // If there's an error in the API response, return the error message to the UI


            $trx = getTrx();

            $user->balance += $issueFee / 100; // Convert amount back to USD before add
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $issueFee / 100;
            $transaction->post_balance = $user->balance;
            $transaction->charge = 00;
            $transaction->trx_type = '+';
            $transaction->details = 'Reversal of Card Issuance Fees';
            $transaction->trx =  $trx;
            $transaction->save();

            $ntrx = getTrx();

            $user->balance += $validatedData['amount'] / 100; // Convert amount back to USD before add
            $user->save();

            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $validatedData['amount'] / 100; // Convert amount back to USD for recording 
            $transaction->post_balance = $user->balance;
            $transaction->charge = 00;
            $transaction->trx_type = '+';
            $transaction->details = 'Reversal of Initial  Card Loading';
            $transaction->trx =  $ntrx;
            $transaction->save();
            $adminNotification = new AdminNotification();
            $adminNotification->user_id = $user->id;
            $adminNotification->title = json_encode($virtualcard_api_response);
            $adminNotification->click_url = urlPath('admin.users.detail', $user->id);
            $adminNotification->save();

            $notify = [['error', $virtualcard_api_response->message]];
            return redirect()->back()->withNotify($notify);
        } else {
            if ($virtualcard_api_response->status == "success") {

                $update = new Fluttercard;
                $update->user_id = $user->id;
                $update->status = $virtualcard_api_response->status;
                $update->card_id = $virtualcard_api_response->data->id;
                $update->account_id = $virtualcard_api_response->data->account_id;
                $update->card_pan = $virtualcard_api_response->data->card_pan;
                $update->card_type = $virtualcard_api_response->data->card_type;
                $update->name_on_card = $virtualcard_api_response->data->name_on_card;
                $update->masked_pan = $virtualcard_api_response->data->masked_pan;
                $update->currency = $virtualcard_api_response->data->currency;
                $update->is_active = $virtualcard_api_response->data->is_active;
                $update->cvv = $virtualcard_api_response->data->cvv;
                $update->expiration = $virtualcard_api_response->data->expiration;
                $update->save();
                $notify[] = ['Success', 'Card Created Successfully'];
                return back()->withNotify($notify)->withInput();
            } else {
                $trx = getTrx();

                $user->balance += $issueFee / 100; // Convert amount back to USD before add
                $user->save();
                $transaction = new Transaction();
                $transaction->user_id = $user->id;
                $transaction->amount = $issueFee / 100;
                $transaction->post_balance = $user->balance;
                $transaction->charge = 00;
                $transaction->trx_type = '+';
                $transaction->details = 'Reversal of Card Issuance Fees';
                $transaction->trx =  $trx;
                $transaction->save();

                $ntrx = getTrx();

                $user->balance += $validatedData['amount'] / 100; // Convert amount back to USD before add
                $user->save();

                $transaction = new Transaction();
                $transaction->user_id = $user->id;
                $transaction->amount = $validatedData['amount'] / 100; // Convert amount back to USD for recording 
                $transaction->post_balance = $user->balance;
                $transaction->charge = 00;
                $transaction->trx_type = '+';
                $transaction->details = 'Reversal of Initial  Card Loading';
                $transaction->trx =  $ntrx;
                $transaction->save();
                $adminNotification = new AdminNotification();
                $adminNotification->user_id = $user->id;
                $adminNotification->title = json_encode($virtualcard_api_response);
                $adminNotification->click_url = urlPath('admin.users.detail', $user->id);
                $adminNotification->save();



                $notify[] = ['error', 'Sorry! There was an error issuing your card contact support'];
                return back()->withNotify($notify)->withInput();
            }
        }
    }
   public function loadfunds(Request $request)
    {
        $user = auth()->user();
        $general = GeneralSetting::first();

        $validator = Validator::make($request->all(), [
            'card_id' => 'required|string',
            'currency' => 'required|string', // Adjust validation rules as needed
            'amount' => 'required|numeric',

        ]);

        // Check if validation fails
        if ($validator->fails()) {
            $notify[] = ['error', 'Validation failed'];
        }
        $validatedData = $validator->validated();

        $card_id = $validatedData['card_id'];
        $currency = $validatedData['currency'];
        // dd( $card_id); die;

        if ($request["currency"] == $general->cur_text && floatval($validatedData['amount']) < 5) {
            $notify[] = ['error', 'Sorry! Minimum Load amount is 5'];
            return back()->withNotify($notify)->withInput();
        }

        // Retrieve the Flutter Load fee percentage from general settings
        $flutter_load = $general->flutter_load; // Assuming flutter_load is the Flutter Load fee percentage
        // dd(floatval($flutter_load)); die;

        // Calculate the fee
        $loadfee = round((floatval($flutter_load)/100)*floatval($validatedData['amount']),2);
        // dd($fee); die;

        if ($currency == 'USD') {
            $usd_amount_float = floatval($validatedData['amount']);
            $usd_to_cents = $usd_amount_float * 100;
            $amount = $usd_to_cents;
            $fee =  $loadfee*100;
            // dd( $fee); die;
        }

         $Totalamount =  $amount + $fee;
        //  dd($Totalamount); die;

        if ($Totalamount > $user->balance * 100) {
            $notify[] = ['error', 'Sorry! insufficient balance in this wallet'];
            return back()->withNotify($notify)->withInput();
        }

        $trx = getTrx();

        $user->balance -= $Totalamount / 100;
        $user->save();
        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = $Totalamount / 100;
        $transaction->post_balance = $user->balance;
        $transaction->charge = 00;
        $transaction->trx_type = '-';
        $transaction->details = 'Funds Loaded to  Card';
        $transaction->trx =  $trx;
        $transaction->save();


        $newcards = new Flutterwave;
        $newcard = $newcards->loadfunds($amount, $currency, $card_id);

        if (empty($newcard)) {
            // Handle the case where loadfunds function fails
            $notify[] = ['error', 'Failed to load funds to the card'];
            return back()->withNotify($notify)->withInput();
        } elseif ($newcard->status == "error") {
            $trx = getTrx();

            $user->balance += $Totalamount / 100;
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $Totalamount / 100;
            $transaction->post_balance = $user->balance;
            $transaction->charge = 00;
            $transaction->trx_type = '+';
            $transaction->details = 'Reversal of  Card load fund';
            $transaction->trx =  $trx;
            $transaction->save();
            $notify = [['error', $newcard->message]];
            return redirect()->back()->withNotify($notify);
        } else {
            // Handle the case where loadfunds function succeeds
            if ($newcard->status == "success") {
                $notify[] = ['Success', 'Card Loaded Successfully'];
                return back()->withNotify($notify)->withInput();
            } else {
                $trx = getTrx();

                $user->balance += $Totalamount / 100;
                $user->save();
                $transaction = new Transaction();
                $transaction->user_id = $user->id;
                $transaction->amount = $Totalamount / 100;
                $transaction->post_balance = $user->balance;
                $transaction->charge = 00;
                $transaction->trx_type = '+';
                $transaction->details = 'Reversal of  Card load fund';
                $transaction->trx =  $trx;
                $transaction->save();

                $notify[] = ['error', 'Sorry! your funds could not be loaded'];
                return back()->withNotify($notify)->withInput();
            }
        }
    }

    public function blockVirtualCard(Request $request)
    {
        $user = auth()->user();

        $newcards = new Flutterwave;
        $newcard = $newcards->blockcard($request->card_id);
        // dd( $newcard); die;
        if (empty($newcard)) {
            // Handle the case where block card function fails
            $notify[] = ['error', 'Something Went Wrong'];
            return back()->withNotify($notify)->withInput();
        } else {
            // Handle the case where block card function succeeds
            if ($newcard->status == "success") {
                Fluttercard::where('user_id', $user->id)
                    ->where('card_id', $request->card_id)
                    ->update(['is_active' => false]);
                $notify[] = ['success', 'Card blocked Successfully'];
                return back()->withNotify($notify)->withInput();
            } else {

                $notify[] = ['error', 'Card has been blocked previously'];
                return back()->withNotify($notify)->withInput();
            }
        }
    }

    public function unblockVirtualCard(Request $request)
    {
        $user = auth()->user();

        $newcards = new Flutterwave;
        $newcard = $newcards->unblockcard($request->card_id);
        // dd( $newcard); die;
        if (empty($newcard)) {
            // Handle the case where unblock card function fails
            $notify[] = ['error', 'Something Went Wrong'];
            return back()->withNotify($notify)->withInput();
        } else {
            // Handle the case where unblock card function succeeds
            if ($newcard->status == "success") {
                Fluttercard::where('user_id', $user->id)
                    ->where('card_id', $request->card_id)
                    ->update(['is_active' => true]);
                $notify[] = ['success', 'Card Unblocked Successfully'];
                return back()->withNotify($notify)->withInput();
            } else {

                $notify[] = ['error', 'Card is not Blocked'];
                return back()->withNotify($notify)->withInput();
            }
        }
    }
}
