@extends($activeTemplate.'layouts.auth_master')
@section('content')

<div class="container main-container" id="main-container">
    <div class="card m-4">
        <div class="card-header">
            <div class="row">
                <div class="col-12 col-sm ">
                    <a href="{{ route('user.dps.plans') }}" class="active btn btn-primary m-2">@lang('DPS Plans')</a>
                    <a href="{{ route('user.dps.list') }}" class="btn btn-secondary m-2">@lang('My DPS List')</a>
                </div>
            </div>
        </div>
        <section class="pt-0 pb-120 section--bg mt-0">
            <div class="container">
                <div class="row justify-content-center mb-none-30 mt-4">
                    <div class="col-lg-12">
                        <div class="custom--card">
                            <div class="card-body p-0">
                                <div class="table-responsive--md">
                                    <table class="table mx-0 datatable1" id="datatable1">
                                        <thead class="">
                                            <tr>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('DPS No. | Plan')</th>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('Amount to Pay')</th>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('Installment')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Next Installment')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('After Matured')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Status')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Action')</th>
                                            </tr>
                                        </thead>
                                        <tbody>

                                            @forelse($allDps as $dps)
                                            <tr>
                                                <td data-label="@lang('DPS No. | Plan')">
                                                    <strong>{{ __($dps->trx) }}</strong>
                                                    <small class="d-block text--base">{{ __($dps->plan->name) }}</small>
                                                </td>

                                                <td data-label="@lang('Amount to Pay')">
                                                    <strong>{{ $general->cur_sym.showAmount($dps->per_installment) }}</strong>
                                                    <small class="text--base d-block">@lang('Per') {{ $dps->installment_interval }} @lang('days')</small>
                                                </td>

                                                <td data-label="@lang('Installment')">
                                                    <strong>@lang('Total') : {{ $dps->total_installment }}</strong>
                                                    <small class="text--base d-block">@lang('Given') : {{ $dps->given_installment }}</small>
                                                </td>

                                                <td data-label="@lang('Next Installment')">
                                                    <strong>{{ showDateTime($dps->next_installment_date, 'd M, Y') }}</strong>
                                                    <small class="text--base d-block">
                                                        {{ diffForHumans($dps->next_installment_date) }}
                                                    </small>
                                                </td>

                                                <td data-label="@lang('After Matured')">
                                                    @php
                                                    $totalDeposit = $dps->per_installment * $dps->total_installment;
                                                    $profit = $totalDeposit * $dps->interest_rate / 100 ;
                                                    @endphp
                                                    <span class="fw-bold">
                                                        {{ $general->cur_sym.showAmount($totalDeposit + $profit) }}
                                                    </span>
                                                    <small class="text--base d-block">
                                                        {{ $general->cur_sym.showAmount($totalDeposit) }}
                                                        + {{ getAmount($dps->interest_rate) }}%
                                                    </small>
                                                </td>

                                                <td data-label="@lang('Status')">
                                                    @if($dps->status == 1)
                                                    <span class="badge bg-success text-white">@lang('Running')</span>
                                                    @elseif($dps->status == 2)
                                                    <span class="badge bg-warning text-white">@lang('Matured')</span>
                                                    @elseif($dps->status == 0)
                                                    <span class="badge bg-danger text-white">@lang('Closed')</span>
                                                    @endif
                                                </td>

                                                <td data-label="@lang('Action')">

                                                    @if($dps->status == 1)
                                                    <button type="button" data-bs-toggle="tooltip" title="@lang('Close')" class="btn btn--base btn-sm cantCloseBtn">
                                                        <i class="la la-wallet"></i>
                                                    </button>
                                                    @elseif($dps->status == 2)
                                                    <button type="button" data-bs-toggle="tooltip" title="@lang('Close')" data-token="{{ encrypt($dps->id) }}" class="btn btn--base btn-sm closeBtn">
                                                        <i class="fas fa-money-bill-alt"></i>
                                                    </button>
                                                    @elseif($dps->status == 0)
                                                    <button type="button" data-bs-toggle="tooltip" title="@lang('Close')" class="btn btn--base btn-sm" disabled>
                                                        <i class="la la-wallet"></i>
                                                    </button>
                                                    @endif

                                                </td>

                                            </tr>
                                            @empty
                                            <tr>
                                                <td colspan="100%" class="text-center">{{ __($emptyMessage) }}</td>
                                            </tr>
                                            @endforelse

                                        </tbody>
                                    </table>
                                    
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- dashboard section end -->

                <div class="modal fade" id="closeFdr" tabindex="-1">
                    <div class="modal-dialog modal-dialog-centered" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <strong class="modal-title">@lang('Close DPS')!</strong>
                                <button type="button" class="btn-close" data-dismiss="modal" aria-label="Close"></button>
                                </a>
                            </div>
                            <form action="{{ route('user.dps.close') }}" method="post">
                                @csrf
                                <input type="hidden" name="user_token" required>
                                <div class="modal-body">
                                    <div class="content">
                                        <p>@lang('Are you sure to withdraw the dps amount?')</p>
                                    </div>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-md btn-secondary" data-dismiss="modal">@lang('No')</button>
                                    <button type="submit" class="btn btn-md btn-primary">@lang('Yes')</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>

                <div class="modal fade" id="cantCloseFdr" tabindex="-1">
                    <div class="modal-dialog modal-dialog-centered" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <strong class="modal-title">@lang('Close DPS')</strong>
                                <button type="button" class="btn-close" data-dismiss="modal" aria-label="Close"></button>
                                </a>
                            </div>
                            <div class="modal-body py-4">
                                <h5 class="text-center text--danger">
                                    @lang('Sorry! you can\'t close a DPS before mature') <strong class="date"></strong> </p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </section>

    </div>
</div>
@endsection
@push('script')
<script>
    (function($) {
        "use strict";
        $('.closeBtn').on('click', function() {
            var modal = $('#closeFdr');
            modal.find('input[name=user_token]').val($(this).data('token'));
            modal.modal('show');
        });

        $('.cantCloseBtn').on('click', function() {
            var modal = $('#cantCloseFdr');
            modal.find('.date').text($(this).data('date'));

            modal.modal('show');
        });

    })(jQuery);
</script>
@endpush


@push('bottom-menu')

<a href="{{ route('user.dps.plans') }}" class="active btn btn-primary m-2">@lang('DPS Plans')</a>
<a href="{{ route('user.dps.list') }}" class="btn btn-secondary m-2">@lang('My DPS List')</a>

@endpush