@extends($activeTemplate.'layouts.auth_master')
@section('content')

<div class="container main-container" id="main-container">
    <div class="card m-4">
        <div class="card-header">
            <div class="row">
                <div class="col-12 col-sm ">
                    <a href="{{ route('user.fdr.plans') }}" class="active btn btn-primary m-2">@lang('FDR Plans')</a>
                    <a href="{{ route('user.fdr.list') }}" class="btn btn-secondary m-2">@lang('My FDR List')</a>
                </div>
            </div>
        </div>
        <section class="pt-0 pb-120 section--bg mt-0">
            <div class="container">
                <div class="row justify-content-center mb-none-30 mt-4">
                    <div class="col-lg-12">
                        <div class="custom--card">
                            <div class="card-body p-0">
                                <div class="table-responsive--md">
                                    <table class="table mx-0 datatable1" id="datatable1">
                                        <thead class="">
                                            <tr>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('FDR No. | Plan')</th>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('Amount')</th>
                                                <th class="desktop tablet mobile" data-priority="2">@lang('Profit')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Next Profit')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Lock In Period')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Status')</th>
                                                <th class="desktop tablet " data-priority="2">@lang('Action')</th>
                                            </tr>
                                        </thead>
                                        <tbody>

                                            @forelse($fdrs as $fdr)
                                            <tr>
                                                <td data-label="@lang('FDR No. | Plan')">
                                                    <strong>{{ __($fdr->trx) }}</strong>
                                                    <small class="d-block text--base">{{ __($fdr->plan->name) }}</small>
                                                </td>

                                                <td data-label="@lang('Amount')">
                                                    <strong>{{ $general->cur_sym.showAmount($fdr->amount) }}</strong>
                                                    <small class="d-block text--base">@lang('With') {{ getAmount($fdr->plan->interest_rate) }}% @lang('Profit Rate')</small>
                                                </td>

                                                <td data-label="@lang('Profit')">
                                                    {{ $general->cur_sym.showAmount($fdr->interest) }}
                                                    <small class="text--base d-block">@lang('Per') {{ $fdr->interest_interval }} @lang('Days')</small>
                                                </td>

                                                <td data-label="@lang('Next Profit')">
                                                    {{ showDateTime($fdr->next_return_date, 'd M, Y') }}
                                                    <small class="d-block text--base">{{ diffForHumans($fdr->next_return_date, 'd M, Y') }}</small>
                                                </td>

                                                <td data-label="@lang('Lock In Period')">
                                                    {{ showDateTime($fdr->locked_date, 'd M, Y') }}
                                                    <small class="d-block text--base">{{ diffForHumans($fdr->locked_date, 'd M, Y') }}</small>

                                                </td>

                                                <td data-label="@lang('Status')">
                                                    @if($fdr->status == 1)
                                                    <span class="badge bg-success text-white">@lang('Running')</span>
                                                    @elseif($fdr->status == 2)
                                                    <span class="badge bg-danger text-white">@lang('Completed')</span>
                                                    @endif
                                                </td>

                                                <td data-label="@lang('Action')">
                                                    @if($fdr->locked_date <= Carbon\Carbon::now() && $fdr->status == 1)
                                                        <button type="button" data-bs-toggle="tooltip" title="@lang('Close')" data-token="{{ encrypt($fdr->id) }}" class="btn btn-primary btn-sm closeBtn">
                                                            <i class="la la-wallet"></i>
                                                        </button>
                                                        @else
                                                        <button type="button" data-bs-toggle="tooltip" title="@lang('Close')" class="btn btn-primary btn-sm disabled">
                                                            <i class="la la-wallet"></i>
                                                        </button>
                                                        @endif
                                                </td>
                                            </tr>
                                            @empty
                                            <tr>
                                                <td colspan="100%" class="text-center">{{ __($emptyMessage) }}</td>
                                            </tr>
                                            @endforelse

                                        </tbody>
                                    </table>
                                    
                                </div>
                            </div>
                        </div>
                    </div>

                </div>

                <!-- dashboard section end -->

                <div class="modal fade" id="closeFdr" tabindex="-1">
                    <div class="modal-dialog modal-dialog-centered" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <strong class="modal-title">@lang('Close FDR')</strong>
                                <button type="button" class="btn-close" data-dismiss="modal" aria-label="Close"></button>
                                </a>
                            </div>
                            <form action="{{ route('user.fdr.close') }}" method="post">
                                @csrf
                                <input type="hidden" name="user_token" required>
                                <div class="modal-body">
                                    <div class="form-group">
                                        <input type="hidden" name="id" class="transferId" required>
                                    </div>
                                    <div class="content">
                                        <p>@lang('Are you sure to close this FDR?')</p>
                                    </div>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-md btn-secondary" data-dismiss="modal">@lang('No')</button>
                                    <button type="submit" class="btn btn-md btn-primary">@lang('Yes')</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>

        </section>
    </div>
</div>
@endsection

@push('script')
<script>
    (function($) {
        "use strict";
        $('.closeBtn').on('click', function() {
            var modal = $('#closeFdr');
            modal.find('input[name=user_token]').val($(this).data('token'));
            modal.modal('show');
        });
    })(jQuery);
</script>
@endpush


@push('bottom-menu')

<a href="{{ route('user.fdr.plans') }}" class="active btn btn-primary m-2">@lang('FDR Plans')</a>
<a href="{{ route('user.fdr.list') }}" class="btn btn-secondary m-2">@lang('My FDR List')</a>

@endpush